Module datafusion_functions_array::array_has
source · Expand description
ScalarUDFImpl definitions for array_has, array_has_all and array_has_any functions.
Structs
Functions
- returns true, if the element appears in the first array, otherwise false.
- returns true if each element of the second array appears in the first array; otherwise, it returns false.
- ScalarFunction that returns a
ScalarUDFfor [$UDF] - returns true if at least one element of the second array appears in the first array; otherwise, it returns false.
- ScalarFunction that returns a
ScalarUDFfor [$UDF] - ScalarFunction that returns a
ScalarUDFfor [$UDF]