Function datafusion_functions_array::cardinality::cardinality
source · pub fn cardinality(array: Expr) -> ExprExpand description
returns the total number of elements in the array.
pub fn cardinality(array: Expr) -> Exprreturns the total number of elements in the array.